@@ -1,3 +1,5 @@
+# encoding: utf-8
+
 from __future__ import absolute_import
 
 import collections
@@ -11,16 +13,16 @@ import curtsies.window
 import curtsies.input
 import curtsies.events
 
-from bpython.curtsiesfrontend.repl import BaseRepl
-from bpython.curtsiesfrontend.coderunner import SystemExitFromCodeGreenlet
-from bpython.curtsiesfrontend.interpreter import Interp
-from bpython import args as bpargs
-from bpython import translations
-from bpython.translations import _
-from bpython.importcompletion import find_iterator
-from bpython.curtsiesfrontend import events as bpythonevents
-from bpython import inspection
-from bpython.repl import extract_exit_value
+from .curtsiesfrontend.repl import BaseRepl
+from .curtsiesfrontend.coderunner import SystemExitFromCodeRunner
+from .curtsiesfrontend.interpreter import Interp
+from . import args as bpargs
+from . import translations
+from .translations import _
+from .importcompletion import find_iterator
+from .curtsiesfrontend import events as bpythonevents
+from . import inspection
+from .repl import extract_exit_value
 
 logger = logging.getLogger(__name__)
 
@@ -30,8 +32,7 @@ repl = None  # global for `from bpython.curtsies import repl`
 
 
 class FullCurtsiesRepl(BaseRepl):
-    def __init__(self, config, locals_, banner, interp=None,
-                 paste=None):
+    def __init__(self, config, locals_, banner, interp=None):
         self.input_generator = curtsies.input.Input(
             keynames='curtsies',
             sigint_event=True,
@@ -87,11 +88,11 @@ class FullCurtsiesRepl(BaseRepl):
         try:
             if e is not None:
                 self.process_event(e)
-        except (SystemExitFromCodeGreenlet, SystemExit) as err:
+        except (SystemExitFromCodeRunner, SystemExit) as err:
             array, cursor_pos = self.paint(
                 about_to_exit=True,
                 user_quit=isinstance(err,
-                                     SystemExitFromCodeGreenlet))
+                                     SystemExitFromCodeRunner))
             scrolled = self.window.render_to_terminal(array, cursor_pos)
             self.scroll_offset += scrolled
             raise
@@ -138,7 +139,7 @@ def main(args=None, locals_=None, banner=None, welcome_message=None):
                    help=_("log debug messages to bpython.log")),
             Option('--paste', '-p', action='store_true',
                    help=_("start by pasting lines of a file into session")),
-            ]))
+        ]))
     if options.log is None:
         options.log = 0
     logging_levels = [logging.ERROR, logging.INFO, logging.DEBUG]
@@ -181,14 +182,14 @@ def main(args=None, locals_=None, banner=None, welcome_message=None):
     if banner is not None:
         print(banner)
     global repl
-    repl = FullCurtsiesRepl(config, locals_, welcome_message, interp, paste)
+    repl = FullCurtsiesRepl(config, locals_, welcome_message, interp)
     try:
         with repl.input_generator:
             with repl.window as win:
                 with repl:
                     repl.height, repl.width = win.t.height, win.t.width
-                    exit_value = repl.mainloop()
-    except (SystemExitFromCodeGreenlet, SystemExit) as e:
+                    exit_value = repl.mainloop(True, paste)
+    except (SystemExitFromCodeRunner, SystemExit) as e:
         exit_value = e.args
     return extract_exit_value(exit_value)
 
